@@ -784,8 +784,8 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
                        "footer"]
     LOCAL_FILES_BASE_DIR = "/etc/bgpd"
 
-    AVAILABLE_VERSION = ["6.0", "6.1", "6.2", "6.3", "6.4", "6.5", "6.6"]
-    DEFAULT_VERSION = "6.5"
+    AVAILABLE_VERSION = ["6.0", "6.1", "6.2", "6.3", "6.4", "6.5", "6.6", "6.7"]
+    DEFAULT_VERSION = "6.6"
 
     IGNORABLE_ISSUES = ["path_hiding", "transit_free_action",
                         "add_path", "max_prefix_action",
@@ -826,6 +826,14 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
             ):
                 res = False
 
+        reject_policy = self.cfg_general["filtering"]["reject_policy"]["policy"]
+        if reject_policy == "tag_and_reject":
+            res = False
+            logging.error(
+                "For OpenBGP, 'reject_policy' can't be set to "
+                "'tag_and_reject'."
+            )
+
         add_path_clients = []
         max_prefix_action_clients = []
         for client in self.cfg_clients.cfg["clients"]:
