@@ -209,15 +209,15 @@ class ValidatorListOf(ConfigParserValidator):
         ConfigParserValidator.__init__(self, *args, **kwargs)
         self.cls = cls
 
-    def _validate(self, l):
-        if not isinstance(l, list):
+    def _validate(self, lst):
+        if not isinstance(lst, list):
             raise ConfigError("Invalid format: must be a list")
 
-        for v in l:
+        for v in lst:
             validator = self.cls()
             v = validator.validate(v)
 
-        return l
+        return lst
 
 class ValidatorPrefixListEntry(ConfigParserValidator):
 
