@@ -221,7 +221,17 @@ class BIRDInstance(DockerInstance):
                     route["filtered"] = option == "filtered"
                 else:
                     if "BGP.as_path:" in line:
-                        route["as_path"] = line.split(": ")[1].strip()
+                        raw_as_path = line.split(": ")[1].strip()
+                        if "{" in raw_as_path:
+                            # Stripping as_set in strings like this:
+                            #   BGP.as_path: 222 333 { 333 333 }
+                            as_path = raw_as_path[0:raw_as_path.index("{")].strip()
+                            as_set = raw_as_path[raw_as_path.index("{") + 1:-1].strip()
+                        else:
+                            as_path = raw_as_path
+                            as_set = None
+                        route["as_path"] = as_path
+                        route["as_set"] = as_set
                     if "BGP.next_hop:" in line:
                         route["next_hop"] = ""
                         next_hops = line.split(": ")[1].strip().split()
